﻿#region Copyright
/// <summary>The ScummVM WPF UI project</summary>
/// <copyright>(c) 2016 MojoTouch</copyright>
/// <author>Ilya Rovensky</author>
#endregion

using System;
using System.Globalization;
using System.Threading;
using System.Windows;
using System.Windows.Input;

namespace WpfInterface
{
    /// <summary>
    /// Tutorial screen
    /// </summary>
    public partial class VideoScreen : Menu
    {
        public VideoScreen() : base(true)
        {
            InitializeComponent();
            // show german tutorial for german culture, english otherwise
            string culture = Thread.CurrentThread.CurrentUICulture.Name.Substring(0, 3).ToLower() == "de-" ? "de" : "en";
            MediaPlayer.Source = new Uri($"{Assets.Path}/tutorial_{culture}.mp4", UriKind.Relative);
            // to allow key preview
            Focusable = true;
            Focus();
        }

        private void ReturnToMainMenu()
        {
            MediaPlayer.Source = null;
            Result = MenuAction.Main;
        }

        private void MediaElement_MediaEnded(object sender, RoutedEventArgs e)
        {
            ReturnToMainMenu();
        }

        private void VideoPlayer_MediaFailed(object sender, ExceptionRoutedEventArgs e)
        {
            UserInterface.Log(e.ErrorException);
        }

        private void Menu_MouseUp(object sender, MouseButtonEventArgs e)
        {
            e.Handled = true;
            ReturnToMainMenu();
        }

        private void Menu_KeyDown(object sender, KeyEventArgs e)
        {
            if (e.Key == Key.Escape)
            {
                e.Handled = true;
                ReturnToMainMenu();
            }
        }
    }
}
